@@ -18,7 +18,7 @@ import os
 
 def render_template(template_name):
     root = os.path.abspath(os.path.dirname(os.path.dirname(__file__)))
-    p = os.path.join(root, "templates", f"{template_name}")
+    p = os.path.join(root, "templates", f"{template_name}.template")
     print(p)
     if os.path.isfile(p):
         with open(p, "r") as rfile:
